==> exabel-data-sdk-4.1.0.tar.gz: exabel-data-sdk-4.1.0/exabel_data_sdk/stubs/exabel/api/management/v1/service_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exabel/api/management/v1/service.proto\x12\x18exabel.api.management.v1\x1a.protoc_gen_openapiv2/options/annotations.protoB\xeb\x02\n\x1ccom.exabel.api.management.v1B\x0cServiceProtoP\x01Z\x1cexabel.com/api/management/v1\x92A\x9b\x02\x12U\n\x15Exabel Management API"5\n\x06Exabel\x12\x17https://www.exabel.com/\x1a\x12support@exabel.com2\x051.0.0\x1a\x19management.api.exabel.com*\x01\x022\x10application/json:\x10application/jsonZ\x1c\n\x1a\n\x07API key\x12\x0f\x08\x02\x1a\tx-api-key \x02b\r\n\x0b\n\x07API key\x12\x00rS\n$More about the Exabel Management API\x12+https://help.exabel.com/docs/management-apib\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exabel.api.management.v1.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1ccom.exabel.api.management.v1B\x0cServiceProtoP\x01Z\x1cexabel.com/api/management/v1\x92A\x9b\x02\x12U\n\x15Exabel Management API"5\n\x06Exabel\x12\x17https://www.exabel.com/\x1a\x12support@exabel.com2\x051.0.0\x1a\x19management.api.exabel.com*\x01\x022\x10application/json:\x10application/jsonZ\x1c\n\x1a\n\x07API key\x12\x0f\x08\x02\x1a\tx-api-key \x02b\r\n\x0b\n\x07API key\x12\x00rS\n$More about the Exabel Management API\x12+https://help.exabel.com/docs/management-api'

==> exabel-data-sdk-4.5.0.tar.gz: exabel-data-sdk-4.5.0/exabel_data_sdk/stubs/exabel/api/management/v1/service_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
from .....protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exabel/api/management/v1/service.proto\x12\x18exabel.api.management.v1\x1a.protoc_gen_openapiv2/options/annotations.protoB\xeb\x02\n\x1ccom.exabel.api.management.v1B\x0cServiceProtoP\x01Z\x1cexabel.com/api/management/v1\x92A\x9b\x02\x12U\n\x15Exabel Management API"5\n\x06Exabel\x12\x17https://www.exabel.com/\x1a\x12support@exabel.com2\x051.0.0\x1a\x19management.api.exabel.com*\x01\x022\x10application/json:\x10application/jsonZ\x1c\n\x1a\n\x07API key\x12\x0f\x08\x02\x1a\tx-api-key \x02b\r\n\x0b\n\x07API key\x12\x00rS\n$More about the Exabel Management API\x12+https://help.exabel.com/docs/management-apib\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exabel.api.management.v1.service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1ccom.exabel.api.management.v1B\x0cServiceProtoP\x01Z\x1cexabel.com/api/management/v1\x92A\x9b\x02\x12U\n\x15Exabel Management API"5\n\x06Exabel\x12\x17https://www.exabel.com/\x1a\x12support@exabel.com2\x051.0.0\x1a\x19management.api.exabel.com*\x01\x022\x10application/json:\x10application/jsonZ\x1c\n\x1a\n\x07API key\x12\x0f\x08\x02\x1a\tx-api-key \x02b\r\n\x0b\n\x07API key\x12\x00rS\n$More about the Exabel Management API\x12+https://help.exabel.com/docs/management-api'
